SegmentationException class

Exception thrown by segmentation operations.

Implemented types

Constructors

SegmentationException(SegmentationError code, String message, [Object? cause])
Creates a segmentation exception.
const

Properties

cause Object?
Underlying cause of the error, if available.
final
code SegmentationError
Error code identifying the type of failure.
final
hashCode int
The hash code for this object.
no setterinherited
message String
Human-readable description of the error.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited