WebDetectTimings class
Per-stage timing accumulator for the web pipeline (microseconds). Populated by FaceDetector.detectFacesFromBytes when FaceDetector.debugTimings is true.
Constructors
Properties
- blendshapeInferUs ↔ int
-
getter/setter pair
- decodeUs ↔ int
-
getter/setter pair
- detections ↔ int
-
getter/setter pair
- detInferUs ↔ int
-
getter/setter pair
- detPreUs ↔ int
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- irisInferUs ↔ int
-
getter/setter pair
- irisPreUs ↔ int
-
getter/setter pair
- meshInferUs ↔ int
-
getter/setter pair
- meshPreUs ↔ int
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- totalUs ↔ int
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJsonUs(
) → Map< String, int> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited