strideCols property

int strideCols
final

Mat column count when reconstructing a Mat from bytes. For BGRA/RGBA this is rowStride ~/ 4 and may exceed width (in which case the consumer should crop to width × height). For YUV this equals width.

Implementation

final int strideCols;