FaceDetector constructor
FaceDetector()
Creates a new face detector instance.
The detector is not ready for use until you call initialize.
Implementation
FaceDetector();
Creates a new face detector instance.
The detector is not ready for use until you call initialize.
FaceDetector();