isSegmentationReady property
bool
get
isSegmentationReady
Returns true if the segmentation model is loaded and ready.
Implementation
bool get isSegmentationReady => _segmentationInitialized;
Returns true if the segmentation model is loaded and ready.
bool get isSegmentationReady => _segmentationInitialized;