inputHeight property
int
get
inputHeight
The expected input height for the embedding model (112 pixels).
Implementation
int get inputHeight => _inH;
The expected input height for the embedding model (112 pixels).
int get inputHeight => _inH;