inputWidth property
int
get
inputWidth
The expected input width for the embedding model (112 pixels).
Implementation
int get inputWidth => _inW;
The expected input width for the embedding model (112 pixels).
int get inputWidth => _inW;