buffer property
The underlying Float32 buffer containing the tensor's raw data.
This provides direct access to the tensor output values without copying.
Implementation
final Float32List buffer;
The underlying Float32 buffer containing the tensor's raw data.
This provides direct access to the tensor output values without copying.
final Float32List buffer;