OutputTensorInfo class
Holds metadata for an output tensor (shape plus its writable buffer).
Constructors
-
OutputTensorInfo(List<
int> shape, Float32List buffer) -
Creates an OutputTensorInfo with the given
shapeandbuffer.
Properties
- buffer → Float32List
-
The underlying Float32 buffer containing the tensor's raw data.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
shape
→ List<
int> -
The dimensions of the tensor (e.g.,
[1, 896, 1]for a 1D output with 896 elements).final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited